@@ -11,6 +11,8 @@ from .latest import Latest
 from .create_file import CreateFile
 from .create_ml_engine import CreateMLEngine
 from .drop_ml_engine import DropMLEngine
+from .create_job import CreateJob
+from .drop_job import DropJob
 
 # Temporary
 CreateDatasource = CreateDatabase
