@@ -1006,13 +1006,17 @@ class MindsDBParser(Parser):
     @_('result_column AS identifier',
        'result_column identifier',
        'result_column AS dquote_string',
-       'result_column dquote_string')
+       'result_column dquote_string',
+       'result_column AS quote_string',
+       'result_column quote_string')
     def result_column(self, p):
         col = p.result_column
         if col.alias:
             raise ParsingException(f'Attempt to provide two aliases for {str(col)}')
         if hasattr(p, 'dquote_string'):
             alias = Identifier(p.dquote_string)
+        elif hasattr(p, 'quote_string'):
+            alias = Identifier(p.quote_string)
         else:
             alias = p.identifier
         col.alias = alias
